==> speex-1.0.4.tar.gz: speex-1.0.4/libspeex/hexc_10_32_table.c <==
/* Copyright (C) 2002 Jean-Marc Valin 
   File: hexc_10_32_table.c
   Codebook for high-band excitation in SB-CELP mode (4000 bps)

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:
   
   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.
   
   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.
   
   - Neither the name of the Xiph.org Foundation nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.
   
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

signed char hexc_10_32_table[320] = {
-3, -2, -1, 0, -4, 5, 35, -40, -9, 13, 
-44, 5, -27, -1, -7, 6, -11, 7, -8, 7, 
19, -14, 15, -4, 9, -10, 10, -8, 10, -9, 
-1, 1, 0, 0, 2, 5, -18, 22, -53, 50, 
1, -23, 50, -36, 15, 3, -13, 14, -10, 6, 
1, 5, -3, 4, -2, 5, -32, 25, 5, -2, 
-1, -4, 1, 11, -29, 26, -6, -15, 30, -18, 
0, 15, -17, 40, -41, 3, 9, -2, -2, 3, 
-3, -1, -5, 2, 21, -6, -16, -21, 23, 2, 
60, 15, 16, -16, -9, 14, 9, -1, 7, -9, 
0, 1, 1, 0, -1, -6, 17, -28, 54, -45, 
-1, 1, -1, -6, -6, 2, 11, 26, -29, -2, 
46, -21, 34, 12, -23, 32, -23, 16, -10, 3, 
66, 19, -20, 24, 7, 11, -3, 0, -3, -1, 
-50, -46, 2, -18, -3, 4, -1, -2, 3, -3, 
-19, 41, -36, 9, 11, -24, 21, -16, 9, -3, 
-25, -3, 10, 18, -9, -2, -5, -1, -5, 6, 
-4, -3, 2, -26, 21, -19, 35, -15, 7, -13, 
17, -19, 39, -43, 48, -31, 16, -9, 7, -2, 
-5, 3, -4, 9, -19, 27, -55, 63, -35, 10, 
26, -44, -2, 9, 4, 1, -6, 8, -9, 5, 
-8, -1, -3, -16, 45, -42, 5, 15, -16, 10, 
0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
-16, 24, -55, 47, -38, 27, -19, 7, -3, 1, 
16, 27, 20, -19, 18, 5, -7, 1, -5, 2, 
-6, 8, -22, 0, -3, -3, 8, -1, 7, -8, 
1, -3, 5, 0, 17, -48, 58, -52, 29, -7, 
-2, 3, -10, 6, -26, 58, -31, 1, -6, 3, 
93, -29, 39, 3, 17, 5, 6, -1, -1, -1, 
27, 13, 10, 19, -7, -34, 12, 10, -4, 9, 
-76, 9, 8, -28, -2, -11, 2, -1, 3, 1, 
-83, 38, -39, 4, -16, -6, -2, -5, 5, -2, 
};

==> speex-1.2.1.tar.gz: speex-1.2.1/libspeex/hexc_10_32_table.c <==
/* Copyright (C) 2002 Jean-Marc Valin
   File: hexc_10_32_table.c
   Codebook for high-band excitation in SB-CELP mode (4000 bps)

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   - Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

   - Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

   - Neither the name of the Xiph.org Foundation nor the names of its
   contributors may be used to endorse or promote products derived from
   this software without specific prior written permission.

   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

const signed char hexc_10_32_table[320] = {
-3, -2, -1, 0, -4, 5, 35, -40, -9, 13,
-44, 5, -27, -1, -7, 6, -11, 7, -8, 7,
19, -14, 15, -4, 9, -10, 10, -8, 10, -9,
-1, 1, 0, 0, 2, 5, -18, 22, -53, 50,
1, -23, 50, -36, 15, 3, -13, 14, -10, 6,
1, 5, -3, 4, -2, 5, -32, 25, 5, -2,
-1, -4, 1, 11, -29, 26, -6, -15, 30, -18,
0, 15, -17, 40, -41, 3, 9, -2, -2, 3,
-3, -1, -5, 2, 21, -6, -16, -21, 23, 2,
60, 15, 16, -16, -9, 14, 9, -1, 7, -9,
0, 1, 1, 0, -1, -6, 17, -28, 54, -45,
-1, 1, -1, -6, -6, 2, 11, 26, -29, -2,
46, -21, 34, 12, -23, 32, -23, 16, -10, 3,
66, 19, -20, 24, 7, 11, -3, 0, -3, -1,
-50, -46, 2, -18, -3, 4, -1, -2, 3, -3,
-19, 41, -36, 9, 11, -24, 21, -16, 9, -3,
-25, -3, 10, 18, -9, -2, -5, -1, -5, 6,
-4, -3, 2, -26, 21, -19, 35, -15, 7, -13,
17, -19, 39, -43, 48, -31, 16, -9, 7, -2,
-5, 3, -4, 9, -19, 27, -55, 63, -35, 10,
26, -44, -2, 9, 4, 1, -6, 8, -9, 5,
-8, -1, -3, -16, 45, -42, 5, 15, -16, 10,
0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-16, 24, -55, 47, -38, 27, -19, 7, -3, 1,
16, 27, 20, -19, 18, 5, -7, 1, -5, 2,
-6, 8, -22, 0, -3, -3, 8, -1, 7, -8,
1, -3, 5, 0, 17, -48, 58, -52, 29, -7,
-2, 3, -10, 6, -26, 58, -31, 1, -6, 3,
93, -29, 39, 3, 17, 5, 6, -1, -1, -1,
27, 13, 10, 19, -7, -34, 12, 10, -4, 9,
-76, 9, 8, -28, -2, -11, 2, -1, 3, 1,
-83, 38, -39, 4, -16, -6, -2, -5, 5, -2,
};
